Руководство пользователя — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »

# Руководство пользователя

В этой части документации по серверу борьбу со спамом “СпамоБорец” освещены вопросы установки, настройки, использования сервера с точки зрения конечного пользователя. Этот раздел является базовым для всех остальных разделов.

- Обзор возможностей СпамоБорца

- Установка СпамоБорца
  - С помощью средств ОС
  - Установка из пакета

- Запуск сервера

- Основные компоненты сервера
  - Домен
    - Примеры
    - Домен по умолчанию
  - Партнер
    - Механизм авторизации партнеров
  - Сообщение
    - Атрибут сообщения
    - Домен атрибута сообщений
    - Домен сообщения
  - Модель анализа сообщений
    - Простая Байесовская модель (BayesModel)
    - DataMining-модель (DataMiningModel)
  - Хранилище данных
    - Хранилище в памяти (DomainMemoryStorage)
    - Хранилище на диске (DomainedDBMStorage)
  - Правила
    - Правила, связанные с моделью анализа сообщений
    - Правила, связанные с логом сообщений
    - Правила валидации
    - Правила анализа текста сообщений
    - Правила проверки на частоту
    - Правила, используемые для тестирования
  - Firewall
    - Синтаксис действий firewall
    - Примеры наборов действий
  - Лог сообщений

- Настройка сервера

Что осталось:
  - spamfighter-create
  - запуск и первые шаги
  - пример настройки

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »